ComparableCoralElementsExtension<E extends Comparable> extension
- on
-
- CoralIterableElements<
E>
- CoralIterableElements<
Properties
-
max
→ Coral<
E> -
Available on CoralIterableElements<
Returns the maximum element in this collection, or throws StateError if empty.E> , provided by the ComparableCoralElementsExtension extensionno setter -
maxOrNull
→ Coral<
E?> -
Available on CoralIterableElements<
Returns the maximum element in this collection, or null if empty.E> , provided by the ComparableCoralElementsExtension extensionno setter -
min
→ Coral<
E> -
Available on CoralIterableElements<
Returns the minimum element in this collection, or throws StateError if empty.E> , provided by the ComparableCoralElementsExtension extensionno setter -
minOrNull
→ Coral<
E?> -
Available on CoralIterableElements<
Returns the minimum element in this collection, or null if empty.E> , provided by the ComparableCoralElementsExtension extensionno setter -
sorted
→ Coral<
List< E> > -
Available on CoralIterableElements<
Returns a new list containing the elements of this collection sorted in ascending order.E> , provided by the ComparableCoralElementsExtension extensionno setter -
sortedDescending
→ Coral<
List< E> > -
Available on CoralIterableElements<
Returns a new list containing the elements of this collection sorted in descending order.E> , provided by the ComparableCoralElementsExtension extensionno setter
Methods
-
isSorted(
[int compare(E a, E b)?]) → Coral< bool> -
Available on CoralIterableElements<
Returns true if this collection is sorted in ascending order.E> , provided by the ComparableCoralElementsExtension extension