GeneralCoralElementsExtension<E> extension
- on
-
- CoralIterableElements<
E>
- CoralIterableElements<
Methods
-
anyIndexed(
bool test(int index, E element)) → Coral< bool> -
Available on CoralIterableElements<
Returns true if any element satisfies an indexed predicateE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
elementAtOrNull(
int index) → Coral< E?> -
Available on CoralIterableElements<
Returns theE> , provided by the GeneralCoralElementsExtension extensionindexth element reactively, or null if out of range. -
everyIndexed(
bool test(int index, E element)) → Coral< bool> -
Available on CoralIterableElements<
Returns true if all elements satisfy an indexed predicateE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
expandIndexed<
T> (Iterable< T> toElements(int index, E element)) → Coral<List< T> > -
Available on CoralIterableElements<
Flattens this collection along with element indices reactively.E> , provided by the GeneralCoralElementsExtension extension -
firstWhereIndexedOrNull(
bool test(int index, E element)) → Coral< E?> -
Available on CoralIterableElements<
Returns the first element that satisfies an indexed predicateE> , provided by the GeneralCoralElementsExtension extensiontestreactively, or null if none. -
firstWhereOrNull(
bool test(E element)) → Coral< E?> -
Available on CoralIterableElements<
Returns the first element that satisfiesE> , provided by the GeneralCoralElementsExtension extensiontestreactively, or null if none. -
foldIndexed<
T> (T initialValue, T combine(int index, T previous, E element)) → Coral< T> -
Available on CoralIterableElements<
Reduces this collection to a single value by iteratively combining elements along with their index and an initial value reactively.E> , provided by the GeneralCoralElementsExtension extension -
groupBy<
K> (K key(E element)) → Coral< Map< K, List< >E> > -
Available on CoralIterableElements<
Legacy alias of groupListsBy.E> , provided by the GeneralCoralElementsExtension extension -
groupFoldBy<
K, G> ({required K key(E element), required G fold(G? previous, E element)}) → Coral< Map< K, G> > -
Available on CoralIterableElements<
Groups and folds elements by a key computed from each element reactively.E> , provided by the GeneralCoralElementsExtension extension -
groupListsBy<
K> (K keyOf(E element)) → Coral< Map< K, List< >E> > -
Available on CoralIterableElements<
Groups elements into lists byE> , provided by the GeneralCoralElementsExtension extensionkeyOfreactively. -
groupSetsBy<
K> (K keyOf(E element)) → Coral< Map< K, Set< >E> > -
Available on CoralIterableElements<
Groups elements into sets byE> , provided by the GeneralCoralElementsExtension extensionkeyOfreactively. -
isSorted(
int compare(E a, E b)) → Coral< bool> -
Available on CoralIterableElements<
Returns true if this collection is sorted byE> , provided by the GeneralCoralElementsExtension extensioncomparereactively. -
isSortedBy<
K extends Comparable> (K keyOf(E element)) → Coral< bool> -
Available on CoralIterableElements<
Returns true if this collection is sorted by the natural order ofE> , provided by the GeneralCoralElementsExtension extensionkeyOfreactively. -
isSortedByCompare<
K> (K keyOf(E element), int compare(K a, K b)) → Coral< bool> -
Available on CoralIterableElements<
Returns true if this collection is sorted byE> , provided by the GeneralCoralElementsExtension extensioncompareofkeyOfreactively. -
lastBy<
K> (K key(E element)) → Coral< Map< K, E> > -
Available on CoralIterableElements<
Groups elements byE> , provided by the GeneralCoralElementsExtension extensionkeyreactively, keeping only the last element for each key. -
lastWhereIndexedOrNull(
bool test(int index, E element)) → Coral< E?> -
Available on CoralIterableElements<
Returns the last element that satisfies an indexed predicateE> , provided by the GeneralCoralElementsExtension extensiontestreactively, or null if none. -
lastWhereOrNull(
bool test(E element)) → Coral< E?> -
Available on CoralIterableElements<
Returns the last element that satisfiesE> , provided by the GeneralCoralElementsExtension extensiontestreactively, or null if none. -
mapIndexed<
T> (T convert(int index, E element)) → Coral< List< T> > -
Available on CoralIterableElements<
Maps each element of this collection along with its index reactively.E> , provided by the GeneralCoralElementsExtension extension -
none(
bool test(E element)) → Coral< bool> -
Available on CoralIterableElements<
Returns true if no elements satisfyE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
noneIndexed(
bool test(int index, E element)) → Coral< bool> -
Available on CoralIterableElements<
Returns true if no elements satisfy an indexed predicateE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
reduceIndexed(
E combine(int index, E previous, E element)) → Coral< E> -
Available on CoralIterableElements<
Reduces this collection to a single value by iteratively combining elements along with their index reactively.E> , provided by the GeneralCoralElementsExtension extension -
sample(
int count, [Random? random]) → Coral< List< E> > -
Available on CoralIterableElements<
SelectsE> , provided by the GeneralCoralElementsExtension extensioncountelements at random from this collection reactively. -
shuffled(
[Random? random]) → Coral< List< E> > -
Available on CoralIterableElements<
Returns a list containing the elements of this collection shuffled reactively.E> , provided by the GeneralCoralElementsExtension extension -
singleWhereIndexedOrNull(
bool test(int index, E element)) → Coral< E?> -
Available on CoralIterableElements<
Returns the single element that satisfies an indexed predicateE> , provided by the GeneralCoralElementsExtension extensiontestreactively, or null if none. -
singleWhereOrNull(
bool test(E element)) → Coral< E?> -
Available on CoralIterableElements<
Returns the single element that satisfiesE> , provided by the GeneralCoralElementsExtension extensiontestreactively, or null if none. -
slices(
int size) → Coral< List< List< >E> > -
Available on CoralIterableElements<
Splits this collection into chunks ofE> , provided by the GeneralCoralElementsExtension extensionsizeelements reactively. -
sorted(
int compare(E a, E b)) → Coral< List< E> > -
Available on CoralIterableElements<
Returns a list containing the elements of this collection sorted byE> , provided by the GeneralCoralElementsExtension extensioncomparereactively. -
sortedBy<
K extends Comparable> (K keyOf(E element)) → Coral< List< E> > -
Available on CoralIterableElements<
Returns a list containing the elements of this collection sorted byE> , provided by the GeneralCoralElementsExtension extensionkeyOfreactively. -
sortedByCompare<
K> (K keyOf(E element), int compare(K a, K b)) → Coral< List< E> > -
Available on CoralIterableElements<
Returns a list containing the elements of this collection sorted byE> , provided by the GeneralCoralElementsExtension extensioncompareofkeyOfreactively. -
splitAfter(
bool test(E element)) → Coral< List< List< >E> > -
Available on CoralIterableElements<
Splits this collection into chunks after elements satisfyingE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
splitAfterIndexed(
bool test(int index, E element)) → Coral< List< List< >E> > -
Available on CoralIterableElements<
Splits this collection into chunks after elements satisfying an indexed predicateE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
splitBefore(
bool test(E element)) → Coral< List< List< >E> > -
Available on CoralIterableElements<
Splits this collection into chunks before elements satisfyingE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
splitBeforeIndexed(
bool test(int index, E element)) → Coral< List< List< >E> > -
Available on CoralIterableElements<
Splits this collection into chunks before elements satisfying an indexed predicateE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
splitBetween(
bool test(E first, E second)) → Coral< List< List< >E> > -
Available on CoralIterableElements<
Splits this collection into chunks between elements satisfyingE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
splitBetweenIndexed(
bool test(int index, E first, E second)) → Coral< List< List< >E> > -
Available on CoralIterableElements<
Splits this collection into chunks between elements satisfying an indexed predicateE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
whereIndexed(
bool test(int index, E element)) → Coral< List< E> > -
Available on CoralIterableElements<
Filters elements of this collection based on an indexed predicateE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
whereNot(
bool test(E element)) → Coral< List< E> > -
Available on CoralIterableElements<
Returns a list of elements that do not satisfyE> , provided by the GeneralCoralElementsExtension extensiontestreactively. -
whereNotIndexed(
bool test(int index, E element)) → Coral< List< E> > -
Available on CoralIterableElements<
Filters elements of this collection based on an indexed predicateE> , provided by the GeneralCoralElementsExtension extensiontestreactively, returning those that do not satisfy it.