IntegerCoralElementsExtension extension
- on
-
- CoralIterableElements<
int>
- CoralIterableElements<
Properties
-
average
→ Coral<
double> -
Available on CoralIterableElements<
Returns the average of the elements in this collection.int> , provided by the IntegerCoralElementsExtension extensionno setter -
max
→ Coral<
int> -
Available on CoralIterableElements<
Returns the maximum element in this collection, or throws StateError if empty.int> , provided by the IntegerCoralElementsExtension extensionno setter -
maxOrNull
→ Coral<
int?> -
Available on CoralIterableElements<
Returns the maximum element in this collection, or null if empty.int> , provided by the IntegerCoralElementsExtension extensionno setter -
min
→ Coral<
int> -
Available on CoralIterableElements<
Returns the minimum element in this collection, or throws StateError if empty.int> , provided by the IntegerCoralElementsExtension extensionno setter -
minOrNull
→ Coral<
int?> -
Available on CoralIterableElements<
Returns the minimum element in this collection, or null if empty.int> , provided by the IntegerCoralElementsExtension extensionno setter -
sum
→ Coral<
int> -
Available on CoralIterableElements<
Returns the sum of the elements in this collection.int> , provided by the IntegerCoralElementsExtension extensionno setter